@@ -45,9 +45,17 @@ extern void Pixmaps_FindLoad (const char * name,
         (const char **)CurrentDefault)) == NULL) \
         error ("can't create internal default pixmap")
 
+    if (name == NULL || name[0] == EOS)
+    {
+	if (CurrentDefault == NULL)
+	    error ("missing image name specification") ;
+
+        UseDefault () ;
+    }
+    else
     if (! File_FindInPath (path, sizeof path, PixmapPath, name))
     {
-        problem ("can't find file \"%s\"", name) ;
+        problem ("can't find image \"%s\"", name) ;
         UseDefault () ;
     }
     else
@@ -185,9 +193,13 @@ extern void Pixmaps_FindLoad (const char * name,
 extern void Pixmaps_LoadMenu (void)
 {
     Pixmap image, mask ;
+    bool saveAutoScale ;
+    saveAutoScale = AutoScale ; /* save old value */
+    AutoScale = false ; /* set temporary value */
     Pixmaps_FindLoad (Menu_GetPixmap (), & image, & mask, NULL, NULL) ;
     DASetShape (mask) ;
     DASetPixmap (image) ;
+    AutoScale = saveAutoScale ; /* restore initial value */
 }
 
 extern void Pixmaps_LoadTile (void)
