@@ -1,3 +1,6 @@
+#define _POSIX_SOURCE
+#define _POSIX_C_SOURCE 199309L
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -139,3 +142,42 @@ extern bool File_FindInPath (char * out, int outSz,
         return false ;
     }
 }
+
+extern char * File_ReadOutputFromCommand (const char * cmd)
+{
+    FILE * out ;
+    char * ret ;
+
+    if ((out = popen (cmd, "r")) == NULL)
+    {
+	error ("when calling command: %s, error: ",
+	    cmd, strerror (errno)) ;
+	ret = NULL ;
+    }
+    else
+    {
+	ret = File_ReadAll (out) ;
+	pclose (out) ;
+
+	/* if return value is correct, remove trailing whitespace */
+	if (ret != NULL)
+	{
+	    char *lastNotWhite, *cursor ;
+	    char c ;
+
+	    cursor = lastNotWhite = ret ;
+
+	    while ((c = *cursor++) != EOS)
+	    {
+		if (strchr (" \t\n", c) == NULL)
+		{
+		    lastNotWhite = cursor ;
+		}
+	    }
+
+	    *lastNotWhite = EOS ;
+	}
+    }
+
+    return ret ;
+}
